@@ -10,11 +10,16 @@ def get_jira():
     from .config import Configuration
     from jira.client import JIRA
     config = Configuration.from_file()
-    options = dict(server="http://{0}".format(config.fqdn))
+    options = dict(server="http://{0}".format(config.jira_fqdn))
     basic_auth = (config.username, config.password)
     return JIRA(options, basic_auth)
 
 
+@cached_function
+def get_custom_fields():
+    return {item['name']: item['id'] for item in get_jira().fields() if item['custom']}
+
+
 @cached_function
 def get_issues__assigned_to_user(user, project=None):
     return get_jira().search_issues(ASSIGNED_ISSUES.format("project={} AND ".format(project) if project else '', user))
